=== modified file 'drizzled/db.cc'
--- drizzled/db.cc	2009-06-11 21:19:36 +0000
+++ drizzled/db.cc	2009-07-10 06:40:04 +0000
@@ -51,15 +51,6 @@
 static void mysql_change_db_impl(Session *session, LEX_STRING *new_db_name);
             
 
-
-/* Structure for database lock */
-typedef struct my_dblock_st
-{
-  char *name;        /* Database name        */
-  uint32_t name_length;  /* Database length name */
-} my_dblock_t;
-
-
 /**
   Return default database collation.
 

=== modified file 'drizzled/foreign_key.h'
--- drizzled/foreign_key.h	2009-06-05 22:51:06 +0000
+++ drizzled/foreign_key.h	2009-07-10 06:40:04 +0000
@@ -34,42 +34,39 @@
 public:
   enum fk_match_opt 
   {
-    FK_MATCH_UNDEF
-  , FK_MATCH_FULL
-  , FK_MATCH_PARTIAL
-  , FK_MATCH_SIMPLE
+    FK_MATCH_UNDEF, 
+    FK_MATCH_FULL, 
+    FK_MATCH_PARTIAL, 
+    FK_MATCH_SIMPLE
   };
   enum fk_option 
   {
-    FK_OPTION_UNDEF
-  , FK_OPTION_RESTRICT
-  , FK_OPTION_CASCADE
-  , FK_OPTION_SET_NULL
-  , FK_OPTION_NO_ACTION
-  , FK_OPTION_DEFAULT
+    FK_OPTION_UNDEF, 
+    FK_OPTION_RESTRICT, 
+    FK_OPTION_CASCADE, 
+    FK_OPTION_SET_NULL, 
+    FK_OPTION_NO_ACTION, 
+    FK_OPTION_DEFAULT
   };
 
   Table_ident *ref_table;
   List<Key_part_spec> ref_columns;
   uint32_t delete_opt, update_opt, match_opt;
-  Foreign_key(const LEX_STRING &name_arg
-            , List<Key_part_spec> &cols
-            , Table_ident *table
-            , List<Key_part_spec> &ref_cols
-            , uint32_t delete_opt_arg
-            , uint32_t update_opt_arg
-            , uint32_t match_opt_arg)
-  :Key(FOREIGN_KEY
-     , name_arg
-     , &default_key_create_info
-     , 0
-     , cols)
-   , ref_table(table)
-   , ref_columns(ref_cols)
-   , delete_opt(delete_opt_arg)
-   , update_opt(update_opt_arg)
-   , match_opt(match_opt_arg)
-  {}
+  Foreign_key(const LEX_STRING &name_arg,
+              List<Key_part_spec> &cols,
+              Table_ident *table,
+              List<Key_part_spec> &ref_cols,
+              uint32_t delete_opt_arg,
+              uint32_t update_opt_arg,
+              uint32_t match_opt_arg) :
+    Key(FOREIGN_KEY, name_arg, &default_key_create_info, 0, cols), ref_table(table),
+    ref_columns(ref_cols),
+    delete_opt(delete_opt_arg),
+    update_opt(update_opt_arg),
+    match_opt(match_opt_arg)
+  { }
+
+
   /**
    * Constructs an (almost) deep copy of this foreign key. Only those
    * elements that are known to never change are not copied.
@@ -77,6 +74,8 @@
    * in Session.
    */
   Foreign_key(const Foreign_key &rhs, MEM_ROOT *mem_root);
+
+
   /**
    * Used to make a clone of this object for ALTER/CREATE TABLE
    * 
@@ -86,6 +85,8 @@
   {
     return new (mem_root) Foreign_key(*this, mem_root);
   }
+
+
   /* Used to validate foreign key options */
   bool validate(List<CreateField> &table_fields);
 };

=== modified file 'drizzled/open_tables_state.h'
--- drizzled/open_tables_state.h	2009-06-08 16:51:22 +0000
+++ drizzled/open_tables_state.h	2009-07-10 06:40:04 +0000
@@ -71,20 +71,16 @@
   ulong	version;
   uint32_t current_tablenr;
 
-  enum enum_flags {
-    BACKUPS_AVAIL = (1U << 0)     /* There are backups available */
-  };
-
   /*
     Flags with information about the open tables state.
   */
-  uint32_t state_flags;
+  bool backups_available;
 
   /*
     This constructor serves for creation of Open_tables_state instances
     which are used as backup storage.
   */
-  Open_tables_state() : state_flags(0U) { }
+  Open_tables_state() : backups_available(false) { }
 
   Open_tables_state(ulong version_arg);
 
@@ -97,7 +93,7 @@
   {
     open_tables= temporary_tables= derived_tables= NULL;
     extra_lock= lock= NULL;
-    state_flags= 0U;
+    backups_available= false;
   }
 };
 

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2009-07-10 01:49:29 +0000
+++ drizzled/session.cc	2009-07-10 06:40:04 +0000
@@ -88,7 +88,7 @@
 }
 
 Open_tables_state::Open_tables_state(ulong version_arg)
-  :version(version_arg), state_flags(0U)
+  :version(version_arg), backups_available(false)
 {
   reset_open_tables_state();
 }
@@ -1660,7 +1660,7 @@
 {
   backup->set_open_tables_state(this);
   reset_open_tables_state();
-  state_flags|= Open_tables_state::BACKUPS_AVAIL;
+  backups_available= false;
 }
 
 
@@ -1991,7 +1991,7 @@
     does not belong to statement for which we do close_thread_tables()).
     TODO: This should be fixed in later releases.
    */
-  if (!(state_flags & Open_tables_state::BACKUPS_AVAIL))
+  if (backups_available == false)
   {
     main_da.can_overwrite_status= true;
     ha_autocommit_or_rollback(this, is_error());

